@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_traffic.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: customer_traffic.php 240 2010-02-05 08:36:35Z d00p $
  */
 
 define('AREA', 'customer');
@@ -75,7 +75,8 @@ if(!is_null($month)
 	                     WHERE `customerid`='" . $userinfo['customerid'] . "'
 	                     AND `month` = '" . $month . "'
 	                     AND `year` = '" . $year . "'");
-	rsort($row = mysql_fetch_row($result));
+	$row = mysql_fetch_row($result);
+	rsort($row);
 	$traf['max'] = ($row[0] > $row[1] ? ($row[0] > $row[2] ? $row[0] : $row[2]) : ($row[1] > $row[2] ? $row[1] : $row[2]));;
 	$result = $db->query("SELECT
                                 SUM(`http`) as 'http', SUM(`ftp_up`) AS 'ftp_up', SUM(`ftp_down`) as 'ftp_down', SUM(`mail`) as 'mail',
