@@ -17,7 +17,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    APS
- * @version    $Id: class.ApsParser.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: class.ApsParser.php 239 2010-02-05 08:23:19Z d00p $
  * @todo		implement charset validation
  *				reconfigure
  *				patch- and versionmanagement
@@ -1710,7 +1710,14 @@ class ApsParser
 			return;
 		}
 
-		$CustomerId = $this->userinfo['customerid'];
+		if(isset($this->userinfo['customerid']))
+		{		
+			$CustomerId = $this->userinfo['customerid'];
+		}
+		else
+		{
+			$CustomerId = -1;
+		}
 		$AdminId = $this->userinfo['adminid'];
 		$PackagesPerSite = $this->settings['aps']['items_per_page'];
 
