@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Logger
- * @version    $Id: class.ticket.php 172 2010-01-30 15:30:47Z d00p $
+ * @version    $Id: class.ticket.php 240 2010-02-05 08:36:35Z d00p $
  * @link       http://www.nutime.de/
  * 
  * Support Tickets - Tickets-Class
@@ -301,12 +301,12 @@ class ticket
 		}
 		else
 		{
-			$admin = $this->db->query_first("SELECT `email` FROM `" . TABLE_PANEL_ADMINS . "` WHERE `adminid`='" . (int)$this->userinfo['adminid'] . "'");
+			$admin = $this->db->query_first("SELECT `name`, email` FROM `" . TABLE_PANEL_ADMINS . "` WHERE `adminid`='" . (int)$this->userinfo['adminid'] . "'");
 			$mail->From = $this->settings['ticket']['noreply_email'];
 			$mail->FromName = $this->settings['ticket']['noreply_name'];
 			$mail->Subject = $mail_subject;
 			$mail->Body = $mail_body;
-			$mail->AddAddress($admin['email'], $admin['firstname'] . ' ' . $admin['name']);
+			$mail->AddAddress($admin['email'], $admin['name']);
 
 			if(!$mail->Send())
 			{
