@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: lenny.inc.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: lenny.inc.php 285 2010-02-11 22:02:24Z d00p $
  */
 
 return Array(
@@ -93,7 +93,7 @@ return Array(
 					'postfix' => Array(
 						'label' => 'Postfix',
 						'commands' => Array(
-							'apt-get install postfix postfix-mysql libsasl2 libsasl2-modules libsasl2-modules-sql',
+							'apt-get install postfix postfix-mysql libsasl2-2 libsasl2-modules libsasl2-modules-sql',
 							'mkdir -p /etc/postfix/sasl',
 							'mkdir -p /var/spool/postfix/etc/pam.d',
 							'mkdir -p /var/spool/postfix/var/run/mysqld',
