@@ -14,14 +14,14 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    System
- * @version    $Id: init.php 189 2010-01-31 13:24:01Z d00p $
+ * @version    $Id: init.php 291 2010-02-14 14:21:37Z d00p $
  */
 
 // prevent Froxlor pages from being cached
 
 header("Cache-Control: no-cache, must-revalidate");
 header("Pragma: no-cache");
-header("Content-type: text/html; charset=utf-8");
+header("Content-type: text/html; charset=iso-8859-1");
 
 // ensure that default timezone is set
 if(function_exists("date_default_timezone_set") && function_exists("date_default_timezone_get"))
@@ -49,7 +49,8 @@ $filename = basename($_SERVER['PHP_SELF']);
 
 if(!file_exists('./lib/userdata.inc.php'))
 {
-	die('You have to <a href="./install/install.php">configure</a> Froxlor first!');
+	$config_hint = file_get_contents('./templates/misc/configurehint.tpl');
+	die($config_hint);
 }
 
 if(!is_readable('./lib/userdata.inc.php'))
