@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: english.lng.php 176 2010-01-30 16:06:16Z d00p $
+ * @version    $Id: english.lng.php 231 2010-02-04 12:42:12Z d00p $
  */
 
 /**
@@ -1290,4 +1290,10 @@ $lng['tasks']['noneoutstanding'] = 'There are currently no outstanding tasks for
 $lng['ticket']['nonexistingcustomer'] = '(deleted customer)';
 $lng['admin']['ticket_nocustomeraddingavailable'] = 'It\'s not possible to open a new support-ticket currently. You first need to add at least one customer.';
 
+// ADDED IN FROXLOR 0.9.1
+
+$lng['admin']['accountdata'] = 'Account Data';
+$lng['admin']['contactdata'] = 'Contact Data';
+$lng['admin']['servicedata'] = 'Service Data';
+
 ?>
