@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: german.lng.php 176 2010-01-30 16:06:16Z d00p $
+ * @version    $Id: german.lng.php 231 2010-02-04 12:42:12Z d00p $
  */
 
 /**
@@ -1270,4 +1270,10 @@ $lng['tasks']['noneoutstanding'] = 'Zur Zeit gibt es keine ausstehenden Aufgaben
 $lng['ticket']['nonexistingcustomer'] = '(gel&ouml;schter Kunde)';
 $lng['admin']['ticket_nocustomeraddingavailable'] = 'Es k&ouml;nnen derzeit keine neuen Support-Tickets er&ouml;ffnet werden. Sie m&uuml;ssen zuerst einen Kunden anlegen';
 
+// ADDED IN FROXLOR 0.9.1
+
+$lng['admin']['accountdata'] = 'Benutzerdaten';
+$lng['admin']['contactdata'] = 'Kontaktdaten';
+$lng['admin']['servicedata'] = 'Dienstleistungsdaten';
+
 ?>
